Exception: Bake::Gem::CommandExecutionError
- Inherits:
-
RuntimeError
- Object
- RuntimeError
- Bake::Gem::CommandExecutionError
- Defined in:
- lib/bake/gem/shell.rb
Overview
Exception raised when a command execution fails.
Instance Attribute Summary collapse
-
#status ⇒ Object
readonly
Returns the value of attribute status.
- #The status object of the failed command.(statusobjectofthefailedcommand.) ⇒ Object readonly
Instance Method Summary collapse
-
#exit_code ⇒ Object
Helper method for convenience.
-
#initialize(message, status) ⇒ CommandExecutionError
constructor
Initialize the exception with the specified message and process status.
Constructor Details
#initialize(message, status) ⇒ CommandExecutionError
Initialize the exception with the specified message and process status.
17 18 19 20 |
# File 'lib/bake/gem/shell.rb', line 17 def initialize(, status) super() @status = status end |
Instance Attribute Details
#status ⇒ Object (readonly)
Returns the value of attribute status.
23 24 25 |
# File 'lib/bake/gem/shell.rb', line 23 def status @status end |
#The status object of the failed command.(statusobjectofthefailedcommand.) ⇒ Object (readonly)
23 |
# File 'lib/bake/gem/shell.rb', line 23 attr_reader :status |
Instance Method Details
#exit_code ⇒ Object
Helper method for convenience.
26 27 28 |
# File 'lib/bake/gem/shell.rb', line 26 def exit_code @status.exitstatus end |